@@ -40,30 +40,10 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 	int result;
 
 	/* 引数解析 */
-	while((result = getopt(argc, argv, "1:5:0b:iIlLmMor:t:vw:")) != -1)
+	while((result = getopt(argc, argv, "0b:iIlLmMor:t:vw:")) != -1)
 	{
 		switch(result)
 		{
-		case '1':	/* SHA1SUMでチェックする */
-			if(oparg->EFFECT == NOT)
-			{
-				oparg->EFFECT = EXIST;
-			}
-			oparg->CHECK = ONE;
-
-			HASH_CHECK_MODE_SET
-			break;
-
-		case '5':	/* MD5SUMでチェックする */
-			if(oparg->EFFECT == NOT)
-			{
-				oparg->EFFECT = EXIST;
-			}
-			oparg->CHECK = FIVE;
-
-			HASH_CHECK_MODE_SET
-			break;
-
 		case '0':	/* コンペアを行わない */
 			if(oparg->EFFECT == NOT)
 			{
@@ -101,17 +81,6 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			}
 			break;
 
-//		case 'c':	/* memcmpでチェックする */
-/*
-			if(oparg->EFFECT == NOT)
-			{
-				oparg->EFFECT = EXIST;
-			}
-			oparg->CHECK = MEMCMP;
-
-			HASH_CHECK_MODE_SET
-			break;
-*/
 		case 'i':	/* 上書き時に確認する */
 			if(oparg->EFFECT == NOT)
 			{
@@ -261,11 +230,6 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 		fprintf(stderr, "引数が正しくありません\n");
 		exit(EXIT_FAILURE);
 	}
-	else if((oparg->CHECK == MEMCMP) && (oparg->L == LOG))
-	{
-		fprintf(stderr, "-lオプションはSHA-1、もしくはMD5で比較する場合のみ有効です\n");
-		exit(EXIT_FAILURE);
-	}
 /*
 	else if(oparg->CHECK == NOT)
 	{
