@@ -1,6 +1,6 @@
 #include <stdio.h>
 
-static char version[] = "0.13.4 beta";
+static char version[] = "0.14.0 beta";
 
 /* 関数プロトタイプ */
 void help(void);
@@ -15,32 +15,12 @@ void help()
 	puts("srcからdstへコピーする。optionとsrcは複数可。dstが存在しない場合は自動的に作成する。");
 	puts("");
 	puts("オプション");
-	puts(" -1 MODE    SHA-1でコンペアを行う。");
-	puts("            MODEが1の場合はコピー直後に、");
-	puts("            2の場合は全コピー終了後に比較する。");
-	puts("            一致しなかった場合はdstを削除する。");
-	puts("            (例 : snowcp -1 1 src dst)");
-	puts("");
-	puts(" -5 MODE    MD5でコンペアを行う。");
-	puts("            MODEが1の場合はコピー直後に、");
-	puts("            2の場合は全コピー終了後に比較する。");
-	puts("            一致しなかった場合はdstを削除する。");
-	puts("            (例 : snowcp -5 1 src dst)");
-	puts("");
-	puts(" -0         ベリファイ・コンペアを行わない。");
-	puts("            (-1、-5、-c、-rオプションを無効にする。)");
+	puts(" -0         ベリファイを行わない。");
+	puts("            (-rオプションを無効にする。)");
 	puts("");
 	puts(" -b NUMBER  バッファの量を指定する（MB単位、デフォルト値は32）。");
 	puts("            (例 : snowcp -b 64 src dst)");
 	puts("");
-/*
-	puts(" -c MODE    memcmpで比較する。");
-	puts("            MODEが1の場合はコピー直後に、");
-	puts("            2の場合は全コピー終了後に比較する。");
-	puts("            一致しなかった場合はdstを削除する。");
-	puts("            (例 : snowcp -c 1 src dst)");
-	puts("");
-*/
 	puts(" -h         ヘルプを表示する。");
 	puts("            (例 : snowcp -h)");
 	puts("");
@@ -53,8 +33,7 @@ void help()
 	puts(" -I         -iオプションを無効にする。");
 	puts("            (例 : snowcp -I src dst)");
 	puts("");
-	puts(" -l         ベリファイ・コンペアのログを保存する。");
-	puts("            -cオプションのログは保存しない。");
+	puts(" -l         ベリファイのログを保存する。");
 	puts("            (例 : snowcp -1 2 -l src dst)");
 	puts("");
 	puts(" -L         -lオプションを無効にする。");
@@ -69,7 +48,7 @@ void help()
 	puts(" -o         設定を保存する。");
 	puts("            (例 : snowcp -o)");
 	puts("");
-	puts(" -r MODE    ベリファイを行う。");
+	puts(" -r MODE    ベリファイ(MD5)を行う。");
 	puts("            MODEが1の場合はコピー直後に、");
 	puts("            2の場合は全コピー終了後にベリファイを実行する。");
 	puts("            一致しなかった場合はdstを削除する。");
