@@ -12,7 +12,6 @@
 #endif
 
 #include "ch_time_and_mod.h" // inline
-#include "compare_hash.h"
 #include "print_error.h" // inline
 #include "struct_CPDD.h"
 #include "struct_CPInfo.h"
@@ -55,27 +54,12 @@
 	}\
 	else \
 	{\
-		/* signalハンドラ用 */\
-		write_now = cpinfo->dst;\
+		write_now = cpinfo->dst;	/* signalハンドラ用 */\
 		open_dst = true;\
 		cpdd->mk_file_count++;\
 	}\
 }
 
-#define HASH_CHECK \
-{\
-	if((open_src == true) && (open_dst == true))\
-	{\
-		compare_hash(oparg, sdir, cpinfo, cpdd);\
-	}\
-	else \
-	{\
-		fprintf(stderr, "ファイルのオープンに失敗しているため、コンペアをスキップします\n");\
-		fprintf(stderr, "src : %s\n", cpinfo->src);\
-		fprintf(stderr, "dst : %s\n", cpinfo->dst);\
-	}\
-}
-
 #define MD5_FINISH \
 {\
 	md5_finish(state, digest);\
@@ -86,7 +70,7 @@
 		sprintf(hex_output + di * 2, "%02x", digest[di]);\
 	}\
 \
-	cpinfo->verify_md5 = hex_output;\
+	cpinfo->src_md5 = hex_output;\
 }
 
 struct verify_data
@@ -218,6 +202,7 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 				fallocate_support = true;
 				o_direct_write_flag = true;
 			}
+/*
 			else if
 			(
 				((tmp[0] == 'n') && (tmp[1] == 't') && (tmp[2] == 'f') && (tmp[3] == 's'))
@@ -232,6 +217,7 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 					exit(EXIT_FAILURE);
 				}
 			}
+*/
 		}
 
 		filesystem_check = true;
@@ -444,7 +430,7 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 			}
 		}
 
-		if(o_direct_open_dst == true)
+		if((o_direct_open_dst == true) && (src_size_local < total_write_local))
 		{
 			if(ftruncate(idst, src_size_local) == -1)
 			{
@@ -454,6 +440,7 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 	}
 	else if((src_size_local == 0) && (open_dst == true))
 	{
+		/* open時にO_TRUNCするようにしたので、ここの処理は必要ない気がする。 */
 		if(ftruncate(idst, 0) == -1)
 		{
 			print_error("ftruncate", __FILE__, __LINE__, cpdd);
@@ -530,42 +517,15 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 	{
 		switch(oparg->CHECK)
 		{
-		case ONE:
-			HASH_CHECK
-			break;
-
-		case FIVE:
-			HASH_CHECK
-			break;
-
 		case V_FIVE:
-			if(cpinfo->verify_md5 == NULL)
-			{
-				if(src_size_local > 0)
-				{
-					fprintf(stderr, "ベリファイをスキップします\n");
-					fprintf(stderr, "dst : %s\n", cpinfo->dst);
-				}
-				else if((src_size_local < 0))
-				{
-					fprintf(stderr, "コピー元のファイサイズが不正です\n");
-					fprintf(stderr, "ベリファイをスキップします\n");
-					fprintf(stderr, "dst : %s\n", cpinfo->dst);
-				}
-			}
-			else if((open_dst == true) && (src_size_local > 0))
+			if((cpinfo->src_md5 != NULL) && (total_write_local > 0) && (cpinfo->d_para == WRITE))
 			{
 				verify_hash(oparg, sdir, cpinfo, cpdd);
 			}
-			else
-			{
-				fprintf(stderr, "ベリファイをスキップします\n");
-				fprintf(stderr, "dst : %s\n", cpinfo->dst);
-			}
 			break;
 
 		default:
-			fprintf(stderr, "コンペアオプションが不正です\n");
+			fprintf(stderr, "ハッシュチェックオプションが不正です\n");
 			break;
 		}
 
