@@ -36,8 +36,6 @@ void write_conf(const SDir *sdir)
 	_Bool verify_flag = false;
 	char hash_check_mode = '@';
 	_Bool hash_check_log_flag = false;
-	_Bool compare_flag = false;
-	char compare_option = '@';
 
 	int buffer_size = 0;
 
@@ -99,84 +97,6 @@ void write_conf(const SDir *sdir)
 		}
 	}
 
-	if(verify_flag == false)
-	{
-		puts("");
-		puts("ファイルコピー後にコンペアを行いますか?");
-		printf("(y / n) :");
-		fflush(stdout);
-
-		INPUT_CHECK_CLEAN
-
-		if(stdin_buf[0] == 'y')
-		{
-			puts("");
-			puts("コンペアオプションを選んでください");
-			puts("1 : SHA-1");
-			puts("5 : MD5");
-			printf("(1 / 5) :");
-			fflush(stdout);
-/*
-			puts("c : 単純比較");
-			printf("(1 / 5 / c) :");
-*/
-
-			INPUT_CHECK_CLEAN
-/*
-			if((stdin_buf[0] == '1') || (stdin_buf[0] == '5') || (stdin_buf[0] == 'c'))
-*/
-			if((stdin_buf[0] == '1') || (stdin_buf[0] == '5'))
-			{
-				compare_flag = true;
-				compare_option = stdin_buf[0];
-
-				puts("");
-				puts("コンペアモードを選んでください");
-				puts("1 : コピー直後にコンペア");
-				puts("2 : 全コピー終了後に一括コンペア");
-				printf("(1 / 2) :");
-				fflush(stdout);
-
-				INPUT_CHECK_CLEAN
-
-				if((stdin_buf[0] == '1') || (stdin_buf[0] == '2'))
-				{
-					hash_check_mode = stdin_buf[0];
-				}
-				else
-				{
-					compare_flag = false;
-					puts("コンペアオプションを無効にします");
-					fflush(stdout);
-				}
-			}
-			else
-			{
-				compare_flag = false;
-				puts("コンペアオプションを無効にします");
-				fflush(stdout);
-			}
-
-/*
-			if((compare == '1') || (compare == '5'))
-*/
-			if(compare_flag == true)
-			{
-				puts("");
-				puts("コンペアのログを保存しますか?");
-				printf("(y / n) :");
-				fflush(stdout);
-
-				INPUT_CHECK_CLEAN
-
-				if(stdin_buf[0] == 'y')
-				{
-					hash_check_log_flag = true;
-				}
-			}
-		}
-	}
-
 	{
 		puts("");
 		puts("バッファのサイズを変更しますか? (初期値は32MB)");
@@ -320,7 +240,6 @@ void write_conf(const SDir *sdir)
 	/* 設定をファイルに保存する */
 	if(
 		(true == verify_flag) ||
-		(true == compare_flag) ||
 		(0 < buffer_size) ||
 		(true == info_flag) ||
 		(true == overwrite_flag) ||
@@ -390,42 +309,6 @@ void write_conf(const SDir *sdir)
 				printf("ベリファイモード : %c\n", hash_check_mode);
 			}
 
-			if(compare_flag == true)
-			{
-				if(fputc(compare_option, config) == EOF)
-				{
-					write_error("fputc");
-				}
-				else if(fputs(",", config) == EOF)
-				{
-					write_error("fputs");
-				}
-				else if(fputc(hash_check_mode, config) == EOF)
-				{
-					write_error("fputc");
-				}
-				else if(fputs("\n", config) == EOF)
-				{
-					write_error("fputs");
-				}
-
-				if(compare_option == '1')
-				{
-					puts("コンペアタイプ : SHA-1");
-				}
-				else if(compare_option == '5')
-				{
-					puts("コンペアタイプ : MD5");
-				}
-/*
-				else
-				{
-					puts("コンペアタイプ : memcmp");
-				}
-*/
-				printf("コンペアモード : %c\n", hash_check_mode);
-			}
-
 			if(hash_check_log_flag == true)
 			{
 				if(
